==> jc-1.4.0.tar.gz: soot/toolkits/graph/MemoryEfficientGraph.h <==
// public class soot.toolkits.graph.MemoryEfficientGraph

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b22bed2885652868 soot_toolkits_graph_HashMutableDirectedGraph
// @dep_class cb70691c6121a67f soot_toolkits_graph_MemoryEfficientGraph

// header file dependencies
// @dep_header soot_toolkits_graph_HashMutableDirectedGraph

#include "soot/toolkits/graph/HashMutableDirectedGraph.h"

#ifndef _JC_soot_toolkits_graph_MemoryEfficientGraph_H_
#define _JC_soot_toolkits_graph_MemoryEfficientGraph_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_MemoryEfficientGraph$sub_refs	_jc_soot_toolkits_graph_MemoryEfficientGraph$sub_refs;
typedef struct _jc_soot_toolkits_graph_MemoryEfficientGraph$sub_nonrefs	_jc_soot_toolkits_graph_MemoryEfficientGraph$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_MemoryEfficientGraph$refs	_jc_soot_toolkits_graph_MemoryEfficientGraph$refs;
typedef struct _jc_soot_toolkits_graph_MemoryEfficientGraph$nonrefs	_jc_soot_toolkits_graph_MemoryEfficientGraph$nonrefs;
typedef struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object	_jc_soot_toolkits_graph_MemoryEfficientGraph$object;

typedef const struct _jc_soot_toolkits_graph_MemoryEfficientGraph$vmethods	_jc_soot_toolkits_graph_MemoryEfficientGraph$vmethods;
typedef const struct _jc_soot_toolkits_graph_MemoryEfficientGraph$vtable	_jc_soot_toolkits_graph_MemoryEfficientGraph$vtable;
typedef const struct _jc_soot_toolkits_graph_MemoryEfficientGraph$vtype	_jc_soot_toolkits_graph_MemoryEfficientGraph$vtype;

// Constructors
extern void _jc_soot_toolkits_graph_MemoryEfficientGraph$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object *);

// Virtual methods
extern void _jc_soot_toolkits_graph_MemoryEfficientGraph$method$addEdge$690d34df2a2949f2(_jc_env *, struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern void _jc_soot_toolkits_graph_MemoryEfficientGraph$method$addNode$f1addc23e03bc49b(_jc_env *, struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object *, struct _jc_java_lang_Object$object *);
extern void _jc_soot_toolkits_graph_MemoryEfficientGraph$method$removeEdge$874ef39500e76399(_jc_env *, struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern void _jc_soot_toolkits_graph_MemoryEfficientGraph$method$removeNode$c0e02f851c8e1faa(_jc_env *, struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_graph_MemoryEfficientGraph$method_info$addEdge$690d34df2a2949f2;
extern _jc_method _jc_soot_toolkits_graph_MemoryEfficientGraph$method_info$addNode$f1addc23e03bc49b;
extern _jc_method _jc_soot_toolkits_graph_MemoryEfficientGraph$method_info$removeEdge$874ef39500e76399;
extern _jc_method _jc_soot_toolkits_graph_MemoryEfficientGraph$method_info$removeNode$c0e02f851c8e1faa;

// Virtual methods structure
struct _jc_soot_toolkits_graph_MemoryEfficientGraph$vmethods {
	void	(*addEdge$690d34df2a2949f2)(_jc_env *, struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	void	(*addNode$f1addc23e03bc49b)(_jc_env *, struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object *, struct _jc_java_lang_Object$object *);
	void	(*removeEdge$874ef39500e76399)(_jc_env *, struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	void	(*removeNode$c0e02f851c8e1faa)(_jc_env *, struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_soot_toolkits_graph_MemoryEfficientGraph$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_HashMutableDirectedGraph$vmethods	soot_toolkits_graph_HashMutableDirectedGraph;
	_jc_soot_toolkits_graph_MemoryEfficientGraph$vmethods	soot_toolkits_graph_MemoryEfficientGraph;
};

// Vtype
struct _jc_soot_toolkits_graph_MemoryEfficientGraph$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_MemoryEfficientGraph$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_MemoryEfficientGraph$sub_refs {
	struct _jc_java_util_HashMap$object	*self;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_MemoryEfficientGraph$refs {
    _jc_soot_toolkits_graph_MemoryEfficientGraph$sub_refs	soot_toolkits_graph_MemoryEfficientGraph;
    _jc_soot_toolkits_graph_HashMutableDirectedGraph$sub_refs	soot_toolkits_graph_HashMutableDirectedGraph;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_MemoryEfficientGraph$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_MemoryEfficientGraph$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_HashMutableDirectedGraph$sub_nonrefs	soot_toolkits_graph_HashMutableDirectedGraph;
    _jc_soot_toolkits_graph_MemoryEfficientGraph$sub_nonrefs	soot_toolkits_graph_MemoryEfficientGraph;
};

// Object instance structure
struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object {
	_jc_soot_toolkits_graph_MemoryEfficientGraph$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_MemoryEfficientGraph$vtype	*vtype;
	_jc_soot_toolkits_graph_MemoryEfficientGraph$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_MemoryEfficientGraph$vtype _jc_soot_toolkits_graph_MemoryEfficientGraph$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_MemoryEfficientGraph, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_MemoryEfficientGraph$class_object;

#endif	/* _JC_soot_toolkits_graph_MemoryEfficientGraph_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/graph/MemoryEfficientGraph.h <==
// public class soot.toolkits.graph.MemoryEfficientGraph

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b22bed2885652868 soot_toolkits_graph_HashMutableDirectedGraph
// @dep_class cb70691c6121a67f soot_toolkits_graph_MemoryEfficientGraph

// header file dependencies
// @dep_header soot_toolkits_graph_HashMutableDirectedGraph

#include "soot/toolkits/graph/HashMutableDirectedGraph.h"

#ifndef _JC_soot_toolkits_graph_MemoryEfficientGraph_H_
#define _JC_soot_toolkits_graph_MemoryEfficientGraph_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_MemoryEfficientGraph$sub_refs	_jc_soot_toolkits_graph_MemoryEfficientGraph$sub_refs;
typedef struct _jc_soot_toolkits_graph_MemoryEfficientGraph$sub_nonrefs	_jc_soot_toolkits_graph_MemoryEfficientGraph$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_MemoryEfficientGraph$refs	_jc_soot_toolkits_graph_MemoryEfficientGraph$refs;
typedef struct _jc_soot_toolkits_graph_MemoryEfficientGraph$nonrefs	_jc_soot_toolkits_graph_MemoryEfficientGraph$nonrefs;
typedef struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object	_jc_soot_toolkits_graph_MemoryEfficientGraph$object;

typedef const struct _jc_soot_toolkits_graph_MemoryEfficientGraph$vmethods	_jc_soot_toolkits_graph_MemoryEfficientGraph$vmethods;
typedef const struct _jc_soot_toolkits_graph_MemoryEfficientGraph$vtable	_jc_soot_toolkits_graph_MemoryEfficientGraph$vtable;
typedef const struct _jc_soot_toolkits_graph_MemoryEfficientGraph$vtype	_jc_soot_toolkits_graph_MemoryEfficientGraph$vtype;

// Constructors
extern void _jc_soot_toolkits_graph_MemoryEfficientGraph$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_toolkits_graph_MemoryEfficientGraph$method$addEdge$690d34df2a2949f2(_jc_env *, struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_graph_MemoryEfficientGraph$method$addNode$f1addc23e03bc49b(_jc_env *, struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_graph_MemoryEfficientGraph$method$removeEdge$874ef39500e76399(_jc_env *, struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_soot_toolkits_graph_MemoryEfficientGraph$method$removeNode$c0e02f851c8e1faa(_jc_env *, struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_graph_MemoryEfficientGraph$method_info$addEdge$690d34df2a2949f2;
extern _jc_method _jc_soot_toolkits_graph_MemoryEfficientGraph$method_info$addNode$f1addc23e03bc49b;
extern _jc_method _jc_soot_toolkits_graph_MemoryEfficientGraph$method_info$removeEdge$874ef39500e76399;
extern _jc_method _jc_soot_toolkits_graph_MemoryEfficientGraph$method_info$removeNode$c0e02f851c8e1faa;

// Virtual methods structure
struct _jc_soot_toolkits_graph_MemoryEfficientGraph$vmethods {
	void	(*addEdge$690d34df2a2949f2)(_jc_env *, struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*addNode$f1addc23e03bc49b)(_jc_env *, struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*removeEdge$874ef39500e76399)(_jc_env *, struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*removeNode$c0e02f851c8e1faa)(_jc_env *, struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_graph_MemoryEfficientGraph$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_HashMutableDirectedGraph$vmethods	soot_toolkits_graph_HashMutableDirectedGraph;
	_jc_soot_toolkits_graph_MemoryEfficientGraph$vmethods	soot_toolkits_graph_MemoryEfficientGraph;
};

// Vtype
struct _jc_soot_toolkits_graph_MemoryEfficientGraph$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_MemoryEfficientGraph$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_MemoryEfficientGraph$sub_refs {
	struct _jc_java_util_HashMap$object	*self;
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_MemoryEfficientGraph$refs {
    _jc_soot_toolkits_graph_MemoryEfficientGraph$sub_refs	soot_toolkits_graph_MemoryEfficientGraph;
    _jc_soot_toolkits_graph_HashMutableDirectedGraph$sub_refs	soot_toolkits_graph_HashMutableDirectedGraph;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_MemoryEfficientGraph$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_MemoryEfficientGraph$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_HashMutableDirectedGraph$sub_nonrefs	soot_toolkits_graph_HashMutableDirectedGraph;
    _jc_soot_toolkits_graph_MemoryEfficientGraph$sub_nonrefs	soot_toolkits_graph_MemoryEfficientGraph;
};

// Object instance structure
struct _jc_soot_toolkits_graph_MemoryEfficientGraph$object {
	_jc_soot_toolkits_graph_MemoryEfficientGraph$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_MemoryEfficientGraph$vtype	*vtype;
	_jc_soot_toolkits_graph_MemoryEfficientGraph$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_MemoryEfficientGraph$vtype _jc_soot_toolkits_graph_MemoryEfficientGraph$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_MemoryEfficientGraph, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_MemoryEfficientGraph$class_object;

#endif	/* _JC_soot_toolkits_graph_MemoryEfficientGraph_H_ */
